@@ -170,12 +170,16 @@ class DeployCmd(cmd.Cmd):
         """ List all stages """
         for index, stage_name in enumerate(self.stage_nums):
             if index == self.cur_stage:
-                comment = " (current stage)"
+                comment = "(current stage)"
+                stage_marker = '*'
             elif index == self.next_stage:
-                comment = " (next stage)"
+                comment = "(next stage)"
+                stage_marker = '>'
             else:
                 comment = ""
-            log.info("Stage %i: %s%s" % (index, stage_name, comment))
+                stage_marker = ' '
+            log.info("%s%2i: %s %s" % (stage_marker, index, stage_name,
+                                       comment))
 
     def write_stage(self):
         if self.cur_stage is not None:
@@ -436,6 +440,7 @@ def main():
     if os.path.exists(options.envvars):
         with open(options.envvars, 'r') as f:
             for line in f:
+                line = line.split('#', 1)[0]
                 set_env(line)
     if options.envs:
         for line in options.envs:
